@@ -1,8 +1,8 @@
 class BlackboardAPIError(Exception):
     """Base exception for all Blackboard API errors."""
 
-class BbPyAPIError(Exception):
-    """Generic exception for all Bbpy errors."""
+class ChawkError(Exception):
+    """Generic exception for all Chawk errors."""
 
 class AuthenticationError(BlackboardAPIError):
     """Raised when authentication fails or token is invalid."""
